defrag_end_function

Attribute Macro defrag_end_function 

#[defrag_end_function]
Proc macro which is set on a function that need to be called whenever server end performs defrag. The function must accept a [&DefragContext]. If defrag end event is not supported by the Redis version the function will never be called.

Example:

#[defrag_end_function]
fn defrag_end(ctx: &DefragContext) { ... }