#[defrag_start_function]Expand description
Proc macro which is set on a function that need to be called whenever server start performs defrag. The function must accept a [&DefragContext]. If defrag start event is not supported by the Redis version the function will never be called.
Example:
ⓘ
#[defrag_start_function]
fn defrag_start(ctx: &DefragContext) { ... }