#[defrag_function]Expand description
Proc macro which is set on a function that need to be called whenever server performs defrag. The function must accept a [&DefragContext]. If defrag is not supported by the Redis version the function will never be called.
Example:
ⓘ
#[defrag_function]
fn defrag(ctx: &DefragContext) { ... }